In order to run tests, simply run `pytest` from terminal.

Building Tests:
Tests can be added with existing tests (which are organized by object) or as new test sets for more complex features. 
All tests should be commented so that it is clear what the test is meant to check for.